@@ -121,7 +121,7 @@ class Sub(Instruction):
         </syntax>
         <descr>
             Performs a subtract operation on the two source registers and
-            stores the result in the destination register. Overflows are 
+            stores the result in the destination register. Overflows are
             ignored.
         </descr>
     """
@@ -177,7 +177,8 @@ class Andi(Instruction):
             Performs a bitwise AND operation on a source registers and a 12-bit
             sign extended immediate and stores the result in the destination
             register. If the bit in both the source register and the immediate
-            is 1, then the destination register gets a 1; otherwise it gets a 0.
+            is 1, then the destination register gets a 1; otherwise it gets a
+            0.
         </descr>
     """
     def fhook(self, ops, vm, line_num):
@@ -192,6 +193,12 @@ class Or(Instruction):
         <syntax>
             OR reg, reg, reg
         </syntax>
+        <descr>
+            Performs a bitwise OR operation on two source registers and stores
+            the result in the destination register. If the bit in both source
+            registers is a 0, then the destination register gets a 0; otherwise
+            it gets a 1.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_reg(ops, vm, self.name, opfunc.or_, line_num)
@@ -205,6 +212,13 @@ class Ori(Instruction):
         <syntax>
             ORI reg, reg, con
         </syntax>
+        <descr>
+            Performs a bitwise OR operation on a source register and a 12-bit
+            sign extended immediate and stores the result in the destination
+            register. If the bit in both the source register and the immediate
+            is 0, then the destination register gets a 0; otherwise it gets a
+            1.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_immediate(ops, vm, self.name, opfunc.or_, line_num)
@@ -218,6 +232,12 @@ class Xor(Instruction):
         <syntax>
             XOR reg, reg, reg
         </syntax>
+        <descr>
+            Performs a bitwise XOR operation on two source registers and stores
+            the result in the destination register. If the bit in the source
+            registers is different, the destination register gets a 1;
+            otherwise it gets a 0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_reg(ops, vm, self.name, opfunc.xor, line_num)
@@ -231,6 +251,13 @@ class Xori(Instruction):
         <syntax>
             XORI reg, reg, con
         </syntax>
+        <descr>
+            Performs a bitwise XOR operation on a source register and a 12-bit
+            sign extended immediate and stores the result in the destination
+            register. If the bit in the source register and the immediate is
+            different, the destination register gets a 1; otherwise it gets a
+            0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_immediate(ops, vm, self.name, opfunc.xor, line_num)
@@ -244,6 +271,11 @@ class Srl(Instruction):
         <syntax>
             SRL reg, reg, reg
         </syntax>
+        <descr>
+            Performs a logical right shift on the register rs1 by the amount
+            specified by the lower 5 bits of rs2. The result is stored in
+            register rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         check_num_args(self.name, ops, 3, line_num)
@@ -262,6 +294,11 @@ class Srli(Instruction):
         <syntax>
             SRLI reg, reg, con
         </syntax>
+        <descr>
+            Performs a logical right shift on the register rs1 by the amount
+            specified by the 12 bit immediate. The result is stored in register
+            rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_immediate(ops, vm, self.name, opfunc.rshift, line_num)
@@ -275,6 +312,11 @@ class Sll(Instruction):
         <syntax>
             SLL reg, reg, reg
         </syntax>
+        <descr>
+            Performs a logical left shift on the register rs1 by the amount
+            specified by the lower 5 bits of register rs2. The result is stored
+            in register rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         check_num_args(self.name, ops, 3, line_num)
@@ -293,6 +335,11 @@ class Slli(Instruction):
         <syntax>
             SLLI reg, reg, con
         </syntax>
+        <descr>
+            Perfors a logical left shift on the register rs1 by the amount
+            specified by the 12 bit immediate. The result is stored in register
+            rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_immediate(ops, vm, self.name, opfunc.lshift, line_num)
@@ -306,6 +353,10 @@ class Slt(Instruction):
         <syntax>
             SLT reg, reg, reg
         </syntax>
+        <descr>
+                Compares the values in rs1 and rs2 and stores a 1 in rd if rs1
+                is less than rs2. Otherwise rd gets a 0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops(self.get_nm(), ops, line_num)
@@ -324,6 +375,10 @@ class Sltu(Instruction):
         <syntax>
             SLTU reg, reg, reg
         </syntax>
+        <descr>
+            Performs an unsigned compare of the values in rs1 and rs2 and
+            stores a 1 in rd if rs1 is less than rs2. Otherwise rd gets a 0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops(self.get_nm(), ops, line_num)
@@ -344,6 +399,11 @@ class Slti(Instruction):
         <syntax>
             SLTI reg, reg, con
         </syntax>
+        <descr>
+            Compares the value in rs1 and the value of the 12-bit sign extended
+            immediate. If rs1 is less than the immediate, rd gets a 1,
+            otherwise it gets a 0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops_imm(self.get_nm(), ops, line_num)
@@ -357,11 +417,16 @@ class Slti(Instruction):
 class Sltiu(Instruction):
     """
         <instr>
-            SLTU
+            SLTIU
         </instr>
         <syntax>
-            SLTU reg, reg, reg
+            SLTIU reg, reg, con
         </syntax>
+        <descr>
+            Performs an unsigned compare of the value in rs1 and the 12-bit
+            sign extended immediate. If rs1 is less than the immediate, rd gets
+            a 1, otherwise it gets a 0.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops_imm(self.get_nm(), ops, line_num)
@@ -382,6 +447,11 @@ class Sra(Instruction):
         <syntax>
             SRA reg, reg, reg
         </syntax>
+        <descr>
+            Performs an arithmetic right shift on the register rs1 by the
+            amount specified by the lower 5 bits of rs2. The result is stored
+            in register rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops(self.get_nm(), ops, line_num)
@@ -404,6 +474,11 @@ class Srai(Instruction):
         <syntax>
             SRAI reg, reg, imm
         </syntax>
+        <descr>
+            Performs an arithmetic right shift on the register rs1 by the
+            amount specified by the 12-bit immediate. The result is stored in
+            register rd.
+        </descr>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2, op3) = get_three_ops_imm(self.get_nm(), ops, line_num)
@@ -426,6 +501,11 @@ class Div(Instruction):
     <syntax>
         DIV reg, reg, reg
     </syntax>
+    <descr>
+        Performs a divide using register rs1 as the dividend and register rs2
+        as the divisor. The result is stored in register rd. To get the
+        remainder, use REM.
+    </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_reg(ops, vm, self.name, opfunc.floordiv, line_num)
@@ -439,6 +519,11 @@ class Divu(Instruction):
     <syntax>
         DIVU reg, reg, reg
     </syntax>
+    <descr>
+        Performs an unsigned divide using register rs1 as the dividend and
+        register rs2 as the divisor. The result is stored in register rd. To
+        get the remainder, use REMU.
+    </descr>
     """
     def fhook(self, ops, vm, line_num):
         check_num_args(self.name, ops, 3, line_num)
@@ -463,6 +548,11 @@ class Rem(Instruction):
     <syntax>
         REM reg, reg, reg
     </syntax>
+    <descr>
+        Performs a divide using register rs1 as the dividend and register rs2
+        as the divisor. The remainder of the divide is stored in register rd.
+        To get the result, use DIV.
+    </descr>
     """
     def fhook(self, ops, vm, line_num):
         three_op_arith_reg(ops, vm, self.name, opfunc.mod, line_num)
@@ -476,6 +566,10 @@ class Remu(Instruction):
     <syntax>
         REMU reg, reg, reg
     </syntax>
+    <descr>
+        Performs an unsigned divide using register rs1 as the dividend and
+        register rs2 as the divisor. The remainder of the divide is stored in
+        register rd. To get the result, use DIVU.
     """
     def fhook(self, ops, vm, line_num):
         check_num_args(self.name, ops, 3, line_num)
@@ -500,63 +594,14 @@ class Lui(Instruction):
         LUI reg, imm
     </syntax>
     <desc>
-        Loads a constant (EXPECTED TO BE 20 BITS MAX)
-        That's been shifted left by 12 bits
+        Places the specified 20-bit immediate in the upper 20 bits of the
+        specified register. Fills the lower 12-bits with zeroes.
     </desc>
     """
     def fhook(self, ops, vm, line_num):
         (op1, op2) = get_two_op_imm(self.get_nm(), ops, line_num)
         if op2.get_val(line_num) > 1048576:
             raise IncorrectImmLength(op2.get_val(line_num), line_num)
-        # print(op2.get_val(line_num))
         op1.set_val(check_overflow(opfunc.lshift(op2.get_val(line_num),
                     12), vm), line_num)
-        # print(op1.get_val(line_num))
         vm.changes.add(op1.get_nm())
-
-
-'''
-# class Auipc(Instruction):
-    """
-    <instr>
-        AUIPC
-    </instr>
-    <syntax>
-        AUIPC reg, reg, reg
-    </syntax>
-    """
-    # Does lui, and then adds that value to the PC
-    # instead of loading to a register.
-
-# class Mulh(Instruction):
-    """
-    <instr>
-        MULH
-    </instr>
-    <syntax>
-        MULH reg, reg, reg
-    </syntax>
-    """
-
-
-# class Mulhu(Instruction):
-    """
-    <instr>
-        MULHU
-    </instr>
-    <syntax>
-        MULHU reg, reg, reg
-    </syntax>
-    """
-
-
-# class Mulhsu(Instruction):
-    """
-    <instr>
-        MULHSU
-    </instr>
-    <syntax>
-        MULHSU reg, reg, reg
-    </syntax>
-    """
-'''
